#
# This file and its contents are supplied under the terms of the
# Common Development and Distribution License ("CDDL"), version 1.0.
# You may only use this file in accordance with the terms of version
# 1.0 of the CDDL.
#
# A full copy of the text of the CDDL should have accompanied this
# source.  A copy of the CDDL is also available via the Internet at
# http://www.illumos.org/license/CDDL.
#

#
# Copyright (c) 2012 by Delphix. All rights reserved.
# Copyright 2014 Garrett D'Amore <garrett@damore.org>
#

include $(SRC)/Makefile.master
include $(SRC)/cmd/Makefile.cmd
include $(SRC)/test/Makefile.com

OBJS32 = $(PROG:%=%.$(MACH).o)
PROG32 = $(PROG).$(MACH)

$(BUILD64) OBJS64 = $(PROG:%=%.$(MACH64).o)
$(BUILD64) PROG64= $(PROG).$(MACH64)

SRCS = $(PROG).c

C99MODE = -xc99=%all
CFLAGS_amd64 = -m64
CFLAGS_i386 = -m32
CFLAGS_sparc = -m32
CFLAGS_sparcv9 = -m64
LINTFLAGS += -DARCH=\"ARCH\"

ROOTOPTPKG = $(ROOT)/opt/libc-tests
TESTDIR = $(ROOTOPTPKG)/tests

CMDS = $(PROG32:%=$(TESTDIR)/%) $(PROG64:%=$(TESTDIR)/%) \
	$(KSHPROG:%=$(TESTDIR)/%) $(ARCHPROG:%=$(TESTDIR)/%)
$(CMDS) := FILEMODE = 0555

all: $(PROG32) $(PROG64) $(KSHPROG) $(ARCHPROG) $(SUBDIRS)

$(PROG32): $(OBJS32)
	$(LINK.c) $(CFLAGS_$(MACH)) $(OBJS32) -o $@ $(LDLIBS)
	$(POST_PROCESS)

$(PROG64): $(OBJS64)
	$(LINK.c) $(CFLAGS_$(MACH64)) $(OBJS64) -o $@ $(LDLIBS)
	$(POST_PROCESS)

$(KSHPROG): $(KSHPROG).ksh
	$(RM) $@
	$(CP) $(KSHPROG).ksh $(@)
	$(CHMOD) +x $@

$(ARCHPROG): ../common/run_arch_tests.ksh
	$(RM) $@
	$(CP) ../common/run_arch_tests.ksh $(@)
	$(CHMOD) +x $@

%.$(MACH).o: %.c
	$(COMPILE.c) -o $@ $(CFLAGS_$(MACH)) -DARCH=\"$(MACH)\" $<

%.$(MACH64).o: %.c
	$(COMPILE.c) -o $@ $(CFLAGS_$(MACH64)) -DARCH=\"$(MACH64)\" $<

install: $(SUBDIRS) $(CMDS)

lint: lint_SRCS

clobber: clean
	-$(RM) $(PROG32) $(PROG64) $(KSHPROG) $(ARCHPROG)

clean:
	-$(RM) $(OBJS32) $(OBJS64)

$(CMDS): $(TESTDIR) $(PROG32) $(PROG64) $(KSHPROG) $(ARCHPROG)

$(TESTDIR):
	$(INS.dir)

$(TESTDIR)/%: %
	$(INS.file)
